.. _modelSuite:

The PyA model suite
===================

The PyAstronomy model suite is a set of implementations of physical models like,
for example, a transit light-curve model. The models are supposed to provide an
interface to the *funcFit* package so that they can be used for fitting. 

.. note:: We provide examples for the individual classes. For a more detailed introduction
          to the capabilities of the funcFit package, we refer to funcFit's tutorial.

Contents:

.. toctree::
    :maxdepth: 2

    ../funcFitDoc/simplemodels.rst
    Transit modeling <xtranDoc.rst>
    radVelDoc/radVel.rst
    keplerEllipseModelDoc.rst
    lineListGaussModelDoc.rst
    astroVoigt.rst
    LyAProfile.rst
    rotBroadProfile.rst